# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section         free
%define nversion        2.3
%define gcj_support     0

Name:           lucene
Version:        2.4.1
Release:        %mkrel 0.0.1
Epoch:          0
Summary:        High-performance, full-featured text search engine
License:        Apache License
URL:            http://lucene.apache.org/
Group:          Development/Java
Source0:        http://archive.apache.org/dist/lucene/java/%{name}-%{version}-src.tar.gz
Source1:        lucene-1.9-OSGi-MANIFEST.MF
Source2:        lucene-1.9-analysis-OSGi-MANIFEST.MF
Patch1:         lucene-2.4.1-db-javadoc.patch
Patch2:         %{name}-2.4.1-fixmanifests.patch
Patch4:         lucli-remove-classpath.patch
BuildRequires:  ant
BuildRequires:  ant-nodeps
BuildRequires:  javacc
BuildRequires:  java-javadoc
BuildRequires:  java-rpmbuild
BuildRequires:  junit
BuildRequires:  jtidy
BuildRequires:  jakarta-commons-digester
BuildRequires:  jline
BuildRequires:  regexp
BuildRequires:  zip
Provides:       lucene-core = %{epoch}:%{version}-%{release}
# previously used by eclipse but no longer needed
Obsoletes:      lucene-devel < %{version}
%if !%{gcj_support}
BuildRequires:  java-devel
BuildArch:      noarch
%else
BuildRequires:  java-gcj-compat-devel
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Jakarta Lucene is a high-performance, full-featured text search engine
written entirely in Java. It is a technology suitable for nearly any
application that requires full-text search, especially cross-platform.

%package javadoc
Summary:        Javadoc for Lucene
Group:          Development/Java

%description javadoc
Javadoc for Lucene.

%package demo
Summary:        Lucene demonstrations and samples
Group:          Development/Java
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description demo
%{summary}.

%package contrib
Summary:        Lucene contributed extensions
Group:          Development/Java
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description contrib
%{summary}.

%prep
%setup -q -n %{name}-%{version}
# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;

%patch1 -p1 -b .db-javadoc
%patch2 -p1 -b .fixmanifests
%patch4

iconv --from=ISO-8859-1 --to=UTF-8 CHANGES.txt > CHANGES.txt.new 

%build
mkdir -p docs
mkdir -p lib
export OPT_JAR_LIST="ant/ant-junit junit"
export CLASSPATH=$(build-classpath jline jtidy regexp commons-digester)
#pushd contrib/db/bdb/lib
#ln -sf $(build-classpath berkeleydb-native) .
#popd
#pushd contrib/db/bdb-je/lib
#ln -sf $(build-classpath berkeleydb) .
#popd
rm -r contrib/db

#FIXME: Tests freeze randomly. Turning on debug messages shows warnings like:

# [junit] GC Warning: Repeated allocation of very large block (appr. size 512000):
# [junit]   May lead to memory leak and poor performance.

# See: http://koji.fedoraproject.org/koji/getfile?taskID=169839&name=build.log
# for an example

ant -Dbuild.sysclasspath=first \
  -Djavacc.home=%{_bindir}/javacc \
  -Djavacc.jar=%{_javadir}/javacc.jar \
  -Djavacc.jar.dir=%{_javadir} \
  -Djavadoc.link=%{_javadocdir}/java \
  -Dversion=%{version} \
  package
#  package test generate-test-reports

# add missing OSGi metadata to manifests
mkdir META-INF
unzip -o build/lucene-core-%{version}.jar META-INF/MANIFEST.MF
cat %{SOURCE1} >> META-INF/MANIFEST.MF
sed -i '/^\r$/d' META-INF/MANIFEST.MF
zip -u build/lucene-core-%{version}.jar META-INF/MANIFEST.MF
unzip -o build/contrib/analyzers/lucene-analyzers-%{version}.jar META-INF/MANIFEST.MF
cat %{SOURCE2} >> META-INF/MANIFEST.MF
sed -i '/^\r$/d' META-INF/MANIFEST.MF
zip -u build/contrib/analyzers/lucene-analyzers-%{version}.jar META-INF/MANIFEST.MF

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}
install -m 0644 build/%{name}-core-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
install -m 0644 build/%{name}-demos-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-demos-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# contrib jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/%{name}-contrib
for c in analyzers ant highlighter lucli memory misc queries similarity snowball spellchecker surround swing wordnet xml-query-parser; do
    install -m 0644 build/contrib/$c/%{name}-${c}-%{version}.jar \
        $RPM_BUILD_ROOT%{_javadir}/%{name}-contrib
done
(cd $RPM_BUILD_ROOT%{_javadir}/%{name}-contrib && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# javadoc
install -d -m 0755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/docs/api/* \
  $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# webapp
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}
install -m 0644 build/%{name}web.war \
  $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc CHANGES.txt LICENSE.txt README.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_datadir}/%{name}-%{version}

%files javadoc
%defattr(-,root,root,-)
%doc LICENSE.txt
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files contrib
%defattr(-,root,root,-)
%{_javadir}/%{name}-contrib
%doc contrib/CHANGES.txt

%files demo
%defattr(-,root,root,-)
%{_javadir}/%{name}-demos-%{version}.jar
%{_javadir}/%{name}-demos.jar


%changelog
* Sun Jan 23 2011 dmorgan <dmorgan> 0:2.4.1-0.0.1.mga1
+ Revision: 34494
- New version 2.4.1
  Add fedora patches
- imported package lucene


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:2.4.0-0.0.3mdv2011.0
+ Revision: 606427
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:2.4.0-0.0.2mdv2010.1
+ Revision: 523214
- rebuilt for 2010.1

* Sun Oct 04 2009 Oden Eriksson <oeriksson@mandriva.com> 0:2.4.0-0.0.1mdv2010.0
+ Revision: 453398
- rediffed one fuzzy patch

* Mon Oct 20 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:2.4.0-0.0.1mdv2009.1
+ Revision: 295816
- new version 2.4.0

* Thu Jul 31 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:2.3.2-0.0.1mdv2009.0
+ Revision: 257242
- fix group
- BR regexp
- BR jline
- BR jakarta-commons-digester
- BR jtidy
- BR junit
- new version 2.3.2

* Tue Mar 04 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.9.1-3.1.5mdv2008.1
+ Revision: 179024
- add zip BR

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.9.1-3.1.3mdv2008.0
+ Revision: 87385
- remove unnecessary Requires(post) on java-gcj-compat
- rebuild to filter out autorequires of GCJ AOT objects

* Fri Aug 24 2007 David Walluck <walluck@mandriva.org> 0:1.9.1-3.1.2mdv2008.0
+ Revision: 70774
- fix build
- fix OSGi manifests

* Fri Jul 27 2007 David Walluck <walluck@mandriva.org> 0:1.9.1-3.1.1mdv2008.0
+ Revision: 56230
- sync with FC8


* Fri Mar 16 2007 Christiaan Welvaart <spturtle@mandriva.org> 1.9.1-3mdv2007.1
+ Revision: 144742
- rebuild for 2007.1

  + David Walluck <walluck@mandriva.org>
    - Import lucene

* Thu May 25 2006 David Walluck <walluck@mandriva.org> 0:1.9.1-2mdv2007.0
- rebuild for libgcj.so.7

* Tue Mar 28 2006 David Walluck <walluck@mandriva.org> 0:1.9.1-1mdk
- 1.9.1

* Thu Mar 02 2006 David Walluck <walluck@mandriva.org> 0:1.9-1mdk
- 1.9

* Wed Jan 18 2006 David Walluck <walluck@mandriva.org> 0:1.4.3-2.5mdk
- fix path to aot-compile-rpm
- BuildRequires: java-devel

* Tue Oct 25 2005 David Walluck <walluck@mandriva.org> 0:1.4.3-2.4mdk
- remove lib/junit-3.8.1.jar binary jar form source zip

* Tue Oct 25 2005 David Walluck <walluck@mandriva.org> 0:1.4.3-2.3mdk
- fix unversioned demos symlink

* Tue Oct 25 2005 David Walluck <walluck@mandriva.org> 0:1.4.3-2.2mdk
- add %%{name}{,-%%{version}}-src.zip (for eclipse)
- add unversioned demos symlink (fix, for eclipse)

* Sat May 28 2005 David Walluck <walluck@mandriva.org> 0:1.4.3-2.1mdk
- release

* Wed Apr 27 2005 Ville Skyttä <scop at jpackage.org> - 0:1.4.3-2jpp
- Add unversioned javadoc dir symlink.
- Crosslink with local JDK javadocs.
- Convert specfile to UTF-8.
- Fix URLs.

* Mon Jan 10 2005 Kaj J. Niemi <kajtzu@fi.basen.net> 0:1.4.3
- 1.4.3

* Tue Aug 24 2004 Fernando Nasser <fnasser at redhat.com> - 0:1.3-3jpp
- Rebuild with Ant 1.6.2

* Wed Jun 02 2004 Randy Watler <rwatler at finali.com> - 0:1.3-2jpp
- Upgrade to Ant 1.6.X

